/**
 * 
 * Clase que gestiona el acceso a una coleccin de elementos
 * del tipo FrecuenciaCaracter
 * 
 */

public class ListaFrecuencias {
	private FrecuenciaCaracter[] frecuencias; // vector de objetos Frecuencia carcter
	private int numFrecuencias; // en este atributo se almacena el nmero de elementos del vector
	
	/**
	 * Constructor, crea un vector objetos del tipo FrecuenciCaracter
	 * de una determinada longitud que se pasa como parmetro y 
	 * inicializa el nmero de objetos de la coleccin a cero
	 * 
	 * @param max tamao mximo de la coleccin de objetos
	 * 
	 */
	public ListaFrecuencias (int max) {
	   frecuencias = new FrecuenciaCaracter[max];
	   numFrecuencias =0;
	}
	
	/**
	 * Mtodo que retorna el nmero de elementos de la coleccin 
	 * @return numFrecuencias nmero de elementos de la coleccin
	 */
	public int longitud() {
		return numFrecuencias;
	}
	
	/**
	 * Mtodo que retorna el elemento de la coleccin que se encuentra en la
	 * posicin que se pasa como parmetro. En caso de intentar acceder a una posicin 
	 * fuera de los lmites del array el mtodo lanza una excepcin.
	 *  
	 * @param pos posicin del objeto que se desea obtener
	 * @return el objeto de la coleccin en la posicin pos
	 * @return IndexOutOfBoundsException()
	 */
	public FrecuenciaCaracter elemento(int pos) {
		if (pos < numFrecuencias){
			return frecuencias[pos];
		}
		else {
			throw new IndexOutOfBoundsException(); 
		}
	}
	
	/**
	 * Mtodo que aade un nuevo elemento de tipo FrecuenciaCaracter en 
	 * la coleccin. El elemento se aade al final e incrementa la cuenta del
	 * nmero de elementos en la coleccin.
	 * En caso de intentar superar el nmero mximo de elementos 
	 * el mtodo lanza una excepcin.
	 *  
	 * @param ele elemento para aadir a la coleccin
	 * @return IndexOutOfBoundsException() en caso de intentar superar el lmite
	 */
	public void aadir(FrecuenciaCaracter ele) {
		if (numFrecuencias < frecuencias.length){
		   frecuencias[numFrecuencias] = ele;
		   numFrecuencias++;
		}
		else {
			throw new IndexOutOfBoundsException();
		}
	}
	
	/**
	 * Mtodo que resetea la coleccin haciendo que el valor del nmero de
	 * elementos valga cero
	 */
	public void reset() {
		numFrecuencias =0;
	}
	
}
